bootstrap

package
v0.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package bootstrap provides application initialization and configuration management.

Package bootstrap provides gRPC server interceptors for logging and request ID tracking with context propagation.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildRequestIDInterceptor

func BuildRequestIDInterceptor() grpc.UnaryServerInterceptor

BuildRequestIDInterceptor creates a gRPC interceptor that adds a unique request ID to the context.

func Config

func Config() *viper.Viper

Config returns the application configuration instance.

func Init

func Init(cmd string)

Init initializes the application with the specified command name.

func InitWithConfigPath

func InitWithConfigPath(cmd string, configPath string)

InitWithConfigPath initializes the application with a custom config path.

func WithLogAttrs

func WithLogAttrs(ctx context.Context, attrs ...slog.Attr) context.Context

WithLogAttrs adds additional log attributes to the context.

Types

This section is empty.

Jump to